Export Package VRC : bcSCA 22post
Update compared VRC:   SCAU22LN  
Only Package       : Yes
Based on sessions  : No
Script sources     : Yes
Function  sources  : Yes
Library sources    : Yes
Creation Date      : 080307 20:11:57
Total file size    : 2195691
---------------------------------------
C = Charts
q = Questions
c = Messages
l = Labels
d = Domains
t = Table Definitions
s = Sessions
p = Scripts
o = Objects
f = Forms
F = Form Dumps
m = Menus
M = Menu Dumps
r = Reports
i = Impl. Functions
S = Subscription Templates
b = Functions
A = Additional Files
h = Help Text Codes
----------------------
qbcttf00001                                           SCA 22post (not expired)
qbcttf00002                                           SCA 22post (not expired)
dbctfacp.otyp                                         SCA 22post (not expired)
dbctfgld.amnt                                         SCA 22post (not expired)
dbctfgld.date                                         SCA 22post (not expired)
dbctfgld.dbcr                                         SCA 22post (not expired)
dbctfgld.dimx                                         SCA 22post (not expired)
dbctfgld.docn                                         SCA 22post (not expired)
dbctfgld.leac                                         SCA 22post (not expired)
dbctfgld.lino                                         SCA 22post (not expired)
dbctfgld.prod                                         SCA 22post (not expired)
dbctfgld.serl                                         SCA 22post (not expired)
dbctfgld.srno                                         SCA 22post (not expired)
dbctfgld.ttyp                                         SCA 22post (not expired)
dbctfgld.year                                         SCA 22post (not expired)
dbcttc.generate                                       SCA 22post (not expired)
tbcttf001                                             SCA 22post (not expired)
tbcttf020                                             SCA 22post (not expired)
tbcttf021                                             SCA 22post (not expired)
tbcttf022                                             SCA 22post (not expired)
sbcttc0201m000                                        SCA 22post (not expired)
sbcttf0202m000                                        SCA 22post (not expired)
sbcttf0203m000                                        SCA 22post (not expired)
sbcttf0220m000                                        SCA 22post (not expired)
sbcttf0237m000                                        SCA 22post (not expired)
sbcttf0238m000                                        SCA 22post (not expired)
sbcttf1206m000                                        SCA 22post (not expired)
sbctti0201m000                                        SCA 22post (not expired)
sbcttt9200m000                                        SCA 22post (not expired)
sbctwh0406m000                                        SCA 22post (not expired)
pbcgct9289                                            SCA 22post (with source) (not expired)
pbcintdlltcfin                                        SCA 22post (with source) (not expired)
pbcrundll000002                                       SCA 22post (with source) (not expired)
pbcrundll0200                                         SCA 22post (with source) (not expired)
pbcrundlloracle                                       SCA 22post (with source) (not expired)
pbcttc0201                                            SCA 22post (with source) (not expired)
pbcttcdll0001                                         SCA 22post (with source) (not expired)
pbcttcdll0007                                         SCA 22post (with source) (not expired)
pbcttf0202                                            SCA 22post (with source) (not expired)
pbcttf0203                                            SCA 22post (with source) (not expired)
pbcttf0220                                            SCA 22post (with source) (not expired)
pbcttf0220a                                           SCA 22post (with source) (not expired)
pbcttf0237                                            SCA 22post (with source) (not expired)
pbcttf0238                                            SCA 22post (with source) (not expired)
pbcttf1206                                            SCA 22post (with source) (not expired)
pbcttfdll0001                                         SCA 22post (with source) (not expired)
pbcttfdll0004                                         SCA 22post (with source) (not expired)
pbcttfdll0006                                         SCA 22post (with source) (not expired)
pbcttfdll0007                                         SCA 22post (with source) (not expired)
pbcttfdll0008                                         SCA 22post (with source) (not expired)
pbcttfdll0202                                         SCA 22post (with source) (not expired)
pbcttfdll0238                                         SCA 22post (with source) (not expired)
pbctti0201                                            SCA 22post (with source) (not expired)
pbcttidll0001                                         SCA 22post (with source) (not expired)
pbcttt9200                                            SCA 22post (with source) (not expired)
pbcttt9201                                            SCA 22post (with source) (not expired)
pbctwh0406                                            SCA 22post (with source) (not expired)
pbctwhdll0001                                         SCA 22post (with source) (not expired)
fbcttc0201m000d2                                      SCA 22post (not expired)
fbcttf0202m000d2                                      SCA 22post (not expired)
fbcttf0203m000d2                                      SCA 22post (not expired)
fbcttf0220m000d2                                      SCA 22post (not expired)
fbcttf0237m000d2                                      SCA 22post (not expired)
fbcttf0238m000d2                                      SCA 22post (not expired)
fbcttf1206m000d2                                      SCA 22post (not expired)
fbctti0201m000d2                                      SCA 22post (not expired)
fbcttt9200m000d2                                      SCA 22post (not expired)
fbctwh0406m000d2                                      SCA 22post (not expired)
rbcttc0201010002                                      SCA 22post (not expired)
rbcttc0201020002                                      SCA 22post (not expired)
rbcttcerrorrep 2                                      SCA 22post (not expired)
rbcttf0202110002                                      SCA 22post (not expired)
rbcttf0202120002                                      SCA 22post (not expired)
rbcttf0220110002                                      SCA 22post (not expired)
rbctti0201000012                                      SCA 22post (not expired)
cbcttc00001                                           SCA 22post (not expired)
cbcttc00002                                           SCA 22post (not expired)
cbcttc00003                                           SCA 22post (not expired)
cbcttc00004                                           SCA 22post (not expired)
cbcttc00005                                           SCA 22post (not expired)
cbcttc00006                                           SCA 22post (not expired)
cbcttc00007                                           SCA 22post (not expired)
cbcttc00008                                           SCA 22post (not expired)
cbcttc00009                                           SCA 22post (not expired)
cbcttc00010                                           SCA 22post (not expired)
cbcttc00011                                           SCA 22post (not expired)
cbcttc00012                                           SCA 22post (not expired)
cbcttc00013                                           SCA 22post (not expired)
cbcttf00005                                           SCA 22post (not expired)
cbcttf00006                                           SCA 22post (not expired)
cbcttf00007                                           SCA 22post (not expired)
cbcttf00008                                           SCA 22post (not expired)
cbcttf00009                                           SCA 22post (not expired)
cbcttf00010                                           SCA 22post (not expired)
cbcttf0202.01                                         SCA 22post (not expired)
cbcttf0202.02                                         SCA 22post (not expired)
cbcttf0202.03                                         SCA 22post (not expired)
cbcttf0202.04                                         SCA 22post (not expired)
cbcttf0202.05                                         SCA 22post (not expired)
cbcttf0202.06                                         SCA 22post (not expired)
cbcttf0202.07                                         SCA 22post (not expired)
cbcttf0202.08                                         SCA 22post (not expired)
cbcttf0202.09                                         SCA 22post (not expired)
cbcttf0202.10                                         SCA 22post (not expired)
cbcttf0202.11                                         SCA 22post (not expired)
cbcttf0202.12                                         SCA 22post (not expired)
cbcttf0202.13                                         SCA 22post (not expired)
cbcttf0238.01                                         SCA 22post (not expired)
cbcttf0238.02                                         SCA 22post (not expired)
cbcttf0238.03                                         SCA 22post (not expired)
cbcttf0238.04                                         SCA 22post (not expired)
cbcttf0238.05                                         SCA 22post (not expired)
cbcttf0238.06                                         SCA 22post (not expired)
cbcttf0238.07                                         SCA 22post (not expired)
cbcttf0238.08                                         SCA 22post (not expired)
cbcttf0238.09                                         SCA 22post (not expired)
cbcttfs0001                                           SCA 22post (not expired)
cbcttfs0002                                           SCA 22post (not expired)
cbcttfs0004                                           SCA 22post (not expired)
cbcttfs0007                                           SCA 22post (not expired)
cbcttfs0008                                           SCA 22post (not expired)
cbcttfs0009                                           SCA 22post (not expired)
cbcttfs0010                                           SCA 22post (not expired)
cbcttfs0011                                           SCA 22post (not expired)
cbcttfs0012                                           SCA 22post (not expired)
cbctti0001.01                                         SCA 22post (not expired)
cbctti0001.02                                         SCA 22post (not expired)
cbcttis0001                                           SCA 22post (not expired)
cbcttis0002                                           SCA 22post (not expired)
cbcttis0003                                           SCA 22post (not expired)
cbcttt0001                                            SCA 22post (not expired)
bbcbic___slm___                                       SCA 22post (with source) (not expired)
obccnv0205                                            SCA 22post
obccnv2101                                            SCA 22post
obccnv2201                                            SCA 22post
obccnv22011                                           SCA 22post
obccnv22012                                           SCA 22post
obccnv4500                                            SCA 22post
obccnv4501                                            SCA 22post
obccnv4502                                            SCA 22post
obccnv5200                                            SCA 22post
obccnv5201                                            SCA 22post
obccnv5202                                            SCA 22post
obccnv5272                                            SCA 22post
obccnv5400                                            SCA 22post
obccnv5402                                            SCA 22post
obccnv5405                                            SCA 22post
obccnv5406                                            SCA 22post
obccnv5471                                            SCA 22post
obccnv5571                                            SCA 22post
obccnv9190                                            SCA 22post
obccnv9191                                            SCA 22post
obccnv9290                                            SCA 22post
obccnv92901                                           SCA 22post
obccnv9291                                            SCA 22post
obccnv9442                                            SCA 22post
obccnv9490                                            SCA 22post
obccnv990                                             SCA 22post
obccnv991                                             SCA 22post
obccnvdll0001                                         SCA 22post
obccnvinsert222                                       SCA 22post
obccnvloganalys                                       SCA 22post
obccnvnedat                                           SCA 22post
obccnvtext                                            SCA 22post
obccnvtextcorr                                        SCA 22post
obcgct000                                             SCA 22post
obcgct0100                                            SCA 22post
obcgct0112                                            SCA 22post
obcgct1251                                            SCA 22post
obcgct1452                                            SCA 22post
obcgct150                                             SCA 22post
obcgct1551                                            SCA 22post
obcgct1552                                            SCA 22post
obcgct300                                             SCA 22post
obcgct301                                             SCA 22post
obcgct302                                             SCA 22post
obcgct303                                             SCA 22post
obcgct304                                             SCA 22post
obcgct3101                                            SCA 22post
obcgct3102                                            SCA 22post
obcgct3103                                            SCA 22post
obcgct4500                                            SCA 22post
obcgct4501                                            SCA 22post
obcgct4502                                            SCA 22post
obcgct6100                                            SCA 22post
obcgct6110                                            SCA 22post
obcgct7186                                            SCA 22post
obcgct7286                                            SCA 22post
obcgct8188                                            SCA 22post
obcgct8189                                            SCA 22post
obcgct8283                                            SCA 22post
obcgct8288                                            SCA 22post
obcgct8289                                            SCA 22post
obcgct8489                                            SCA 22post
obcgct888                                             SCA 22post
obcgct889                                             SCA 22post
obcgct9188                                            SCA 22post
obcgct9189                                            SCA 22post
obcgct9285                                            SCA 22post
obcgct9289                                            SCA 22post
obcgct989                                             SCA 22post
obcgctdllcommon                                       SCA 22post
obcgctdllmail                                         SCA 22post
obcgcteasy                                            SCA 22post
obcgctmigwizard                                       SCA 22post
obcgctmysql                                           SCA 22post
obcgctntdll                                           SCA 22post
obcgctoracle                                          SCA 22post
obcgcttest                                            SCA 22post
obcgctwizdll                                          SCA 22post
obcintdlltcfin                                        SCA 22post
obcrun0000                                            SCA 22post
obcrun0207                                            SCA 22post
obcrun0507                                            SCA 22post
obcrun80501                                           SCA 22post
obcrun90501                                           SCA 22post
obcrun90502                                           SCA 22post
obcrun90504                                           SCA 22post
obcrun90505                                           SCA 22post
obcrun90506                                           SCA 22post
obcrun90507                                           SCA 22post
obcrun90508                                           SCA 22post
obcrun9599                                            SCA 22post
obcrundbload                                          SCA 22post
obcrundll000001                                       SCA 22post
obcrundll000002                                       SCA 22post
obcrundll0100                                         SCA 22post
obcrundll0200                                         SCA 22post
obcrundllcommon                                       SCA 22post
obcrundllconect                                       SCA 22post
obcrundlldb2                                          SCA 22post
obcrundllinform                                       SCA 22post
obcrundllmssql                                        SCA 22post
obcrundllmysql                                        SCA 22post
obcrundlloracle                                       SCA 22post
obcrunmysql                                           SCA 22post
obcrunonpload                                         SCA 22post
obcruntext                                            SCA 22post
obcttc0201                                            SCA 22post
obcttcdll0001                                         SCA 22post
obcttcdll0007                                         SCA 22post
obcttf0202                                            SCA 22post
obcttf0203                                            SCA 22post
obcttf0220                                            SCA 22post
obcttf0220a                                           SCA 22post
obcttf0237                                            SCA 22post
obcttf0238                                            SCA 22post
obcttf1206                                            SCA 22post
obcttfdll0001                                         SCA 22post
obcttfdll0004                                         SCA 22post
obcttfdll0006                                         SCA 22post
obcttfdll0007                                         SCA 22post
obcttfdll0008                                         SCA 22post
obcttfdll0202                                         SCA 22post
obcttfdll0238                                         SCA 22post
obctti0201                                            SCA 22post
obcttidll0001                                         SCA 22post
obcttt9200                                            SCA 22post
obcttt9201                                            SCA 22post
obctwh0406                                            SCA 22post
obctwhdll0001                                         SCA 22post
obcttc0201010002                                      SCA 22post
obcttc0201020002                                      SCA 22post
obcttcerrorrep 2                                      SCA 22post
obcttf0202110002                                      SCA 22post
obcttf0202120002                                      SCA 22post
obcttf0220110002                                      SCA 22post
obctti0201000012                                      SCA 22post
lbcbcgen.selection  109                               SCA 22post (not expired)
lbcbcttc.error.mess 113                               SCA 22post (not expired)
lbcbcttc.index      113                               SCA 22post (not expired)
lbcbcttc.prim.key   121                               SCA 22post (not expired)
lbcbcttc.table      108                               SCA 22post (not expired)
lbcbcttc0200.01     111                               SCA 22post (not expired)
lbcbcttc0200.02     115                               SCA 22post (not expired)
lbcbcttc0201.01     106                               SCA 22post (not expired)
lbcbcttc0201.02     131                               SCA 22post (not expired)
lbcbcttc0201.03     119                               SCA 22post (not expired)
lbcbcttc0201.04     115                               SCA 22post (not expired)
lbcbcttc0201.05     123                               SCA 22post (not expired)
lbcbcttc0201.06     119                               SCA 22post (not expired)
lbcbcttc0201.12     145                               SCA 22post (not expired)
lbcbcttc0201.13     217                               SCA 22post (not expired)
lbcbcttc0201.14     212                               SCA 22post (not expired)
lbcbcttc0201.15     119                               SCA 22post (not expired)
lbcbcttf001.acce    108                               SCA 22post (not expired)
lbcbcttf001.accf    116                               SCA 22post (not expired)
lbcbcttf001.adtp    115                               SCA 22post (not expired)
lbcbcttf001.amnt    120                               SCA 22post (not expired)
lbcbcttf001.amth    123                               SCA 22post (not expired)
lbcbcttf001.bpid    116                               SCA 22post (not expired)
lbcbcttf001.ccty.f  107                               SCA 22post (not expired)
lbcbcttf001.ccur    120                               SCA 22post (not expired)
lbcbcttf001.core    121                               SCA 22post (not expired)
lbcbcttf001.corr    110                               SCA 22post (not expired)
lbcbcttf001.cprj.f  107                               SCA 22post (not expired)
lbcbcttf001.cust.f  108                               SCA 22post (not expired)
lbcbcttf001.cwar.f  109                               SCA 22post (not expired)
lbcbcttf001.dbcr    112                               SCA 22post (not expired)
lbcbcttf001.dim1    111                               SCA 22post (not expired)
lbcbcttf001.dim2    111                               SCA 22post (not expired)
lbcbcttf001.dim3    111                               SCA 22post (not expired)
lbcbcttf001.dim4    111                               SCA 22post (not expired)
lbcbcttf001.dim5    111                               SCA 22post (not expired)
lbcbcttf001.docn    108                               SCA 22post (not expired)
lbcbcttf001.docn    115                               SCA 22post (not expired)
lbcbcttf001.edes    117                               SCA 22post (not expired)
lbcbcttf001.erro    113                               SCA 22post (not expired)
lbcbcttf001.fcmp    117                               SCA 22post (not expired)
lbcbcttf001.fitr    121                               SCA 22post (not expired)
lbcbcttf001.guid    117                               SCA 22post (not expired)
lbcbcttf001.item.f  104                               SCA 22post (not expired)
lbcbcttf001.koor    113                               SCA 22post (not expired)
lbcbcttf001.leac    114                               SCA 22post (not expired)
lbcbcttf001.line    111                               SCA 22post (not expired)
lbcbcttf001.lino    104                               SCA 22post (not expired)
lbcbcttf001.lino    115                               SCA 22post (not expired)
lbcbcttf001.ocom    116                               SCA 22post (not expired)
lbcbcttf001.orno    112                               SCA 22post (not expired)
lbcbcttf001.pono    108                               SCA 22post (not expired)
lbcbcttf001.prin    107                               SCA 22post (not expired)
lbcbcttf001.proc    109                               SCA 22post (not expired)
lbcbcttf001.srno    126                               SCA 22post (not expired)
lbcbcttf001.tmpk    137                               SCA 22post (not expired)
lbcbcttf001.trdt    108                               SCA 22post (not expired)
lbcbcttf001.tror    118                               SCA 22post (not expired)
lbcbcttf002.amnt    106                               SCA 22post (not expired)
lbcbcttf002.amth    111                               SCA 22post (not expired)
lbcbcttf002.btno    112                               SCA 22post (not expired)
lbcbcttf002.ccur    108                               SCA 22post (not expired)
lbcbcttf002.cpcp    120                               SCA 22post (not expired)
lbcbcttf002.crdt    116                               SCA 22post (not expired)
lbcbcttf002.crus    110                               SCA 22post (not expired)
lbcbcttf002.cuni    104                               SCA 22post (not expired)
lbcbcttf002.dcdt    113                               SCA 22post (not expired)
lbcbcttf002.fper    113                               SCA 22post (not expired)
lbcbcttf002.fyer    111                               SCA 22post (not expired)
lbcbcttf002.nper    117                               SCA 22post (not expired)
lbcbcttf002.nuni    115                               SCA 22post (not expired)
lbcbcttf002.podt    112                               SCA 22post (not expired)
lbcbcttf002.pous    109                               SCA 22post (not expired)
lbcbcttf002.qty1    110                               SCA 22post (not expired)
lbcbcttf002.qty2    110                               SCA 22post (not expired)
lbcbcttf002.rate    113                               SCA 22post (not expired)
lbcbcttf002.ratf    111                               SCA 22post (not expired)
lbcbcttf002.refr    109                               SCA 22post (not expired)
lbcbcttf002.rper    116                               SCA 22post (not expired)
lbcbcttf002.ryer    114                               SCA 22post (not expired)
lbcbcttf002.vper    110                               SCA 22post (not expired)
lbcbcttf002.vyer    108                               SCA 22post (not expired)
lbcbcttf004.sern    108                               SCA 22post (not expired)
lbcbcttf006.dimx    109                               SCA 22post (not expired)
lbcbcttf006.mitm.f  109                               SCA 22post (not expired)
lbcbcttf006.supp.f  108                               SCA 22post (not expired)
lbcbcttf011.ttyp    116                               SCA 22post (not expired)
lbcbcttf020.crdt    113                               SCA 22post (not expired)
lbcbcttf020.docn    108                               SCA 22post (not expired)
lbcbcttf020.fitr    121                               SCA 22post (not expired)
lbcbcttf020.frot    107                               SCA 22post (not expired)
lbcbcttf020.koor    113                               SCA 22post (not expired)
lbcbcttf020.line    111                               SCA 22post (not expired)
lbcbcttf020.lino    104                               SCA 22post (not expired)
lbcbcttf020.ocom    116                               SCA 22post (not expired)
lbcbcttf020.orno    112                               SCA 22post (not expired)
lbcbcttf020.pono    108                               SCA 22post (not expired)
lbcbcttf020.prin    107                               SCA 22post (not expired)
lbcbcttf020.proc    109                               SCA 22post (not expired)
lbcbcttf020.trdt    108                               SCA 22post (not expired)
lbcbcttf020.tror    118                               SCA 22post (not expired)
lbcbcttf020.usgr    110                               SCA 22post (not expired)
lbcbcttf0202.09     207                               SCA 22post (not expired)
lbcbcttf0203.01     136                               SCA 22post (not expired)
lbcbcttf0203.valid  108                               SCA 22post (not expired)
lbcbcttf021.amnt    106                               SCA 22post (not expired)
lbcbcttf021.amth    111                               SCA 22post (not expired)
lbcbcttf021.btno    112                               SCA 22post (not expired)
lbcbcttf021.ccur    108                               SCA 22post (not expired)
lbcbcttf021.cpcp    120                               SCA 22post (not expired)
lbcbcttf021.crdt    116                               SCA 22post (not expired)
lbcbcttf021.crus    110                               SCA 22post (not expired)
lbcbcttf021.cuni    104                               SCA 22post (not expired)
lbcbcttf021.cwoc    110                               SCA 22post (not expired)
lbcbcttf021.dcdt    113                               SCA 22post (not expired)
lbcbcttf021.fper    113                               SCA 22post (not expired)
lbcbcttf021.fyer    111                               SCA 22post (not expired)
lbcbcttf021.nper    117                               SCA 22post (not expired)
lbcbcttf021.nuni    115                               SCA 22post (not expired)
lbcbcttf021.podt    112                               SCA 22post (not expired)
lbcbcttf021.pous    109                               SCA 22post (not expired)
lbcbcttf021.qty1    110                               SCA 22post (not expired)
lbcbcttf021.qty2    110                               SCA 22post (not expired)
lbcbcttf021.ratd    109                               SCA 22post (not expired)
lbcbcttf021.rate    113                               SCA 22post (not expired)
lbcbcttf021.ratf    111                               SCA 22post (not expired)
lbcbcttf021.refr    109                               SCA 22post (not expired)
lbcbcttf021.rper    116                               SCA 22post (not expired)
lbcbcttf021.rtyp    109                               SCA 22post (not expired)
lbcbcttf021.ryer    114                               SCA 22post (not expired)
lbcbcttf021.vper    110                               SCA 22post (not expired)
lbcbcttf021.vyer    108                               SCA 22post (not expired)
lbcbcttf022.amnt    106                               SCA 22post (not expired)
lbcbcttf022.amth    111                               SCA 22post (not expired)
lbcbcttf022.ccur    108                               SCA 22post (not expired)
lbcbcttf022.cpcp    120                               SCA 22post (not expired)
lbcbcttf022.cuni    104                               SCA 22post (not expired)
lbcbcttf022.cwoc    110                               SCA 22post (not expired)
lbcbcttf022.fper    113                               SCA 22post (not expired)
lbcbcttf022.fyer    111                               SCA 22post (not expired)
lbcbcttf022.nuni    115                               SCA 22post (not expired)
lbcbcttf022.ratd    109                               SCA 22post (not expired)
lbcbcttf022.rate    113                               SCA 22post (not expired)
lbcbcttf022.ratf    111                               SCA 22post (not expired)
lbcbcttf022.rper    116                               SCA 22post (not expired)
lbcbcttf022.rtyp    109                               SCA 22post (not expired)
lbcbcttf022.ryer    114                               SCA 22post (not expired)
lbcbcttf022.vper    110                               SCA 22post (not expired)
lbcbcttf022.vyer    108                               SCA 22post (not expired)
lbcbcttt9200.01     138                               SCA 22post (not expired)
lbcbcttt9200.02     115                               SCA 22post (not expired)
lbccisli.dino       208                               SCA 22post (not expired)
lbccisli.ortp       110                               SCA 22post (not expired)
lbccisli.seqn       104                               SCA 22post (not expired)
lbccisli.slcp       308                               SCA 22post (not expired)
lbccisli.slso       309                               SCA 22post (not expired)
lbccisli240.oset    103                               SCA 22post (not expired)
lbccisli245.boid    209                               SCA 22post (not expired)
lbccisli245.borf    125                               SCA 22post (not expired)
lbccnv.total.order  115                               SCA 22post (not expired)
lbcprod.order       215                               SCA 22post (not expired)
lbcserialnumber     113                               SCA 22post (not expired)
lbcseries           106                               SCA 22post (not expired)
lbcsfc000.absh      124                               SCA 22post (not expired)
lbcsfc000.inab      163                               SCA 22post (not expired)
lbcsfc000.serg      135                               SCA 22post (not expired)
lbcsimulate         108                               SCA 22post (not expired)
lbctfacp.otyp009    108                               SCA 22post (not expired)
lbctfacp.otyp010    105                               SCA 22post (not expired)
lbctfacp.otyp012    108                               SCA 22post (not expired)
lbctfacp.otyp013    117                               SCA 22post (not expired)
lbctfacp.otyp014    112                               SCA 22post (not expired)
lbctfgld.dbcr003    106                               SCA 22post (not expired)
lbctfgld.dbcr004    105                               SCA 22post (not expired)
lbcttc.field1       107                               SCA 22post (not expired)
lbcttc.field2       107                               SCA 22post (not expired)
lbcttc.generate001  106                               SCA 22post (not expired)
lbcttc.generate002  110                               SCA 22post (not expired)
lbcttc.generate003  110                               SCA 22post (not expired)
lbcttc.key          103                               SCA 22post (not expired)
lbcttc.key.desc     115                               SCA 22post (not expired)
lbcttc000000001001  115                               SCA 22post (not expired)
lbcttc000000011002  111                               SCA 22post (not expired)
lbcttc000000021002  115                               SCA 22post (not expired)
lbcttc000010011002  118                               SCA 22post (not expired)
lbcttc000010021001  128                               SCA 22post (not expired)
lbcttc000010031002  131                               SCA 22post (not expired)
lbcttc000010041001  119                               SCA 22post (not expired)
lbcttc000010051001  119                               SCA 22post (not expired)
lbcttc000020011002  122                               SCA 22post (not expired)
lbcttc000020021001  123                               SCA 22post (not expired)
lbcttc000020031001  133                               SCA 22post (not expired)
lbcttc000020041001  129                               SCA 22post (not expired)
lbcttc000020051001  123                               SCA 22post (not expired)
lbcttc000020061001  123                               SCA 22post (not expired)
lbcttc000020071001  135                               SCA 22post (not expired)
lbcttc0201.01       112                               SCA 22post (not expired)
lbcttc0201.02       103                               SCA 22post (not expired)
lbcttc0201.02       109                               SCA 22post (not expired)
lbcttc0201.03       103                               SCA 22post (not expired)
lbcttc0201.03       109                               SCA 22post (not expired)
lbcttc020101000001  129                               SCA 22post (not expired)
lbcttc020102000001  130                               SCA 22post (not expired)
lbcttc0201m000001   123                               SCA 22post (not expired)
lbcttcmigratio1001  123                               SCA 22post (not expired)
lbcttf.bal.acc      165                               SCA 22post (not expired)
lbcttf.closed       106                               SCA 22post (not expired)
lbcttf.open         104                               SCA 22post (not expired)
lbcttf.opening.bal  168                               SCA 22post (not expired)
lbcttf.periods      107                               SCA 22post (not expired)
lbcttf000010011001  110                               SCA 22post (not expired)
lbcttf001001        127                               SCA 22post (not expired)
lbcttf001002        137                               SCA 22post (not expired)
lbcttf00101002      136                               SCA 22post (not expired)
lbcttf002002        124                               SCA 22post (not expired)
lbcttf003002        146                               SCA 22post (not expired)
lbcttf020002        137                               SCA 22post (not expired)
lbcttf02001002      134                               SCA 22post (not expired)
lbcttf02002002      140                               SCA 22post (not expired)
lbcttf0202.01       113                               SCA 22post (not expired)
lbcttf0202.02       108                               SCA 22post (not expired)
lbcttf0202.03       114                               SCA 22post (not expired)
lbcttf0202.04       112                               SCA 22post (not expired)
lbcttf0202.05       115                               SCA 22post (not expired)
lbcttf0202.06       118                               SCA 22post (not expired)
lbcttf0202.07       209                               SCA 22post (not expired)
lbcttf0202.08       208                               SCA 22post (not expired)
lbcttf0202.10       206                               SCA 22post (not expired)
lbcttf0202.11       213                               SCA 22post (not expired)
lbcttf0202.12       107                               SCA 22post (not expired)
lbcttf0202.12       114                               SCA 22post (not expired)
lbcttf020211000001  149                               SCA 22post (not expired)
lbcttf020212000001  147                               SCA 22post (not expired)
lbcttf0202m000001   132                               SCA 22post (not expired)
lbcttf0203.continue 108                               SCA 22post (not expired)
lbcttf0203001       136                               SCA 22post (not expired)
lbcttf0203m000001   136                               SCA 22post (not expired)
lbcttf021002        123                               SCA 22post (not expired)
lbcttf02101002      128                               SCA 22post (not expired)
lbcttf022002        146                               SCA 22post (not expired)
lbcttf022003        124                               SCA 22post (not expired)
lbcttf02201002      128                               SCA 22post (not expired)
lbcttf0220m000001   132                               SCA 22post (not expired)
lbcttf0237m000001   165                               SCA 22post (not expired)
lbcttf0238.01       110                               SCA 22post (not expired)
lbcttf0238.02       116                               SCA 22post (not expired)
lbcttf0238m000001   133                               SCA 22post (not expired)
lbcttf100000001001  110                               SCA 22post (not expired)
lbcttf1206m000001   152                               SCA 22post (not expired)
lbcttfs0203.01      117                               SCA 22post (not expired)
lbctti.ex.serno     134                               SCA 22post (not expired)
lbctti020100001001  144                               SCA 22post (not expired)
lbctti0201m000001   124                               SCA 22post (not expired)
lbcttt9200m000001   119                               SCA 22post (not expired)
lbctwh.pro          127                               SCA 22post (not expired)
lbctwh0406m000001   129                               SCA 22post (not expired)
Fbccnv4501m00012                                      SCA 22post
Fbccnv4502m00012                                      SCA 22post
Fbccnv7598m000d2                                      SCA 22post
Fbccnv9588m000d2                                      SCA 22post
Fbcttc0201m000d2                                      SCA 22post
Fbcttf0202m000d2                                      SCA 22post
Fbcttf0203m000d2                                      SCA 22post
Fbcttf0220m000d2                                      SCA 22post
Fbcttf0237m000d2                                      SCA 22post
Fbcttf0238m000d2                                      SCA 22post
Fbcttf1206m000d2                                      SCA 22post
Fbctti0201m000d2                                      SCA 22post
Fbcttt9200m000d2                                      SCA 22post
Fbctwh0406m000d2                                      SCA 22post
Mbccnvauto    12                                      SCA 22post
Mbccnvcodalign12                                      SCA 22post
Mbccnvdatavali12                                      SCA 22post
Mbccnvnrecords12                                      SCA 22post
Mbccnvreport  12                                      SCA 22post
Mbccnvtrunutl 12                                      SCA 22post
Mbccnvutility 12                                      SCA 22post
Mbcgctconver  12                                      SCA 22post
Mbcgctconvert 12                                      SCA 22post
Mbcgctmigratio12                                      SCA 22post
Mbcgctmigwizar12                                      SCA 22post
Mbcgctparam   12                                      SCA 22post
Mbcgctpreconv 12                                      SCA 22post
Mbcttc0000000012                                      SCA 22post
Mbcttc0000000112                                      SCA 22post
Mbcttc0000000212                                      SCA 22post
Mbcttc0000100112                                      SCA 22post
Mbcttc0000100212                                      SCA 22post
Mbcttc0000100312                                      SCA 22post
Mbcttc0000100412                                      SCA 22post
Mbcttc0000100512                                      SCA 22post
Mbcttc0000200112                                      SCA 22post
Mbcttc0000200212                                      SCA 22post
Mbcttc0000200312                                      SCA 22post
Mbcttc0000200412                                      SCA 22post
Mbcttc0000200512                                      SCA 22post
Mbcttc0000200612                                      SCA 22post
Mbcttc0000200712                                      SCA 22post
Mbcttcmigratio12                                      SCA 22post
